package backend

import (
	"context"
	"encoding/json"
	"kpt-pasture/model"

	"gitee.com/xuyiping_admin/pkg/xerr"
)

// AFIMILK 阿菲金品牌实现
type AFIMILK struct {
	store *StoreEntry
}

func (a *AFIMILK) SaveData(ctx context.Context, body *model.MilkHallBody) error {
	content := body.Content
	if len(content) <= 0 {
		return nil
	}

	afiMilkList := make([]*model.AFIMilkHallOriginal, 0)
	if err := json.Unmarshal(content, &afiMilkList); err != nil {
		return xerr.WithStack(err)
	}
	pastureData := &model.PastureList{}
	if err := a.store.DB.Model(pastureData).
		Where("farm_id = ?", body.FarmId).
		First(pastureData).Error; err != nil {
		return xerr.WithStack(err)
	}

	milkOriginalList := make([]*model.MilkOriginal, 0)
	for _, afiMilk := range afiMilkList {
		milkOriginalList = append(milkOriginalList, model.NewAFIMilkOriginal(pastureData.Id, body.MilkHallNumber, afiMilk))
	}

	if len(milkOriginalList) > 0 {
		if err := a.store.DB.Model(new(model.MilkOriginal)).
			Create(milkOriginalList).Error; err != nil {
			return xerr.WithStack(err)
		}
	}

	return nil
}

type AFI struct {
	store *StoreEntry
}

func (a *AFI) SaveData(ctx context.Context, body *model.MilkHallBody) error {
	return nil
}
